from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BRepBuilderAPI import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.TopTools import *
from OCC.Core.Draft import *
from OCC.Core.Geom import *
from OCC.Core.GeomAbs import *
from OCC.Core.BRepFill import *
from OCC.Core.BRepOffset import *
from OCC.Core.BRepPrimAPI import *
from OCC.Core.GeomFill import *
from OCC.Core.Law import *
from OCC.Core.Approx import *

BRepOffsetAPI_Sewing = NewType('BRepOffsetAPI_Sewing', BRepBuilderAPI_Sewing)

class BRepOffsetAPI_SequenceOfSequenceOfReal:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TColStd_SequenceOfReal: ...
    def Last(self) -> TColStd_SequenceOfReal: ...
    def Length(self) -> int: ...
    def Append(self, theItem: TColStd_SequenceOfReal) -> TColStd_SequenceOfReal: ...
    def Prepend(self, theItem: TColStd_SequenceOfReal) -> TColStd_SequenceOfReal: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TColStd_SequenceOfReal: ...
    def SetValue(self, theIndex: int, theValue: TColStd_SequenceOfReal) -> None: ...

class BRepOffsetAPI_SequenceOfSequenceOfShape:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> TopTools_SequenceOfShape: ...
    def Last(self) -> TopTools_SequenceOfShape: ...
    def Length(self) -> int: ...
    def Append(self, theItem: TopTools_SequenceOfShape) -> TopTools_SequenceOfShape: ...
    def Prepend(self, theItem: TopTools_SequenceOfShape) -> TopTools_SequenceOfShape: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> TopTools_SequenceOfShape: ...
    def SetValue(self, theIndex: int, theValue: TopTools_SequenceOfShape) -> None: ...

class BRepOffsetAPI_DraftAngle(BRepBuilderAPI_ModifyShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape) -> None: ...
	def Add(self, F: TopoDS_Face, Direction: gp_Dir, Angle: float, NeutralPlane: gp_Pln, Flag: Optional[bool] = True) -> None: ...
	def AddDone(self) -> bool: ...
	def Build(self) -> None: ...
	def Clear(self) -> None: ...
	def ConnectedFaces(self, F: TopoDS_Face) -> TopTools_ListOfShape: ...
	def CorrectWires(self) -> None: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def Init(self, S: TopoDS_Shape) -> None: ...
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def ModifiedFaces(self) -> TopTools_ListOfShape: ...
	def ModifiedShape(self, S: TopoDS_Shape) -> TopoDS_Shape: ...
	def ProblematicShape(self) -> TopoDS_Shape: ...
	def Remove(self, F: TopoDS_Face) -> None: ...
	def Status(self) -> Draft_ErrorStatus: ...

class BRepOffsetAPI_FindContigousEdges:
	def __init__(self, tolerance: Optional[float] = 1.0e-06, option: Optional[bool] = True) -> None: ...
	def Add(self, shape: TopoDS_Shape) -> None: ...
	def ContigousEdge(self, index: int) -> TopoDS_Edge: ...
	def ContigousEdgeCouple(self, index: int) -> TopTools_ListOfShape: ...
	def DegeneratedShape(self, index: int) -> TopoDS_Shape: ...
	def Dump(self) -> None: ...
	def Init(self, tolerance: float, option: bool) -> None: ...
	def IsDegenerated(self, shape: TopoDS_Shape) -> bool: ...
	def IsModified(self, shape: TopoDS_Shape) -> bool: ...
	def Modified(self, shape: TopoDS_Shape) -> TopoDS_Shape: ...
	def NbContigousEdges(self) -> int: ...
	def NbDegeneratedShapes(self) -> int: ...
	def Perform(self) -> None: ...
	def SectionToBoundary(self, section: TopoDS_Edge) -> TopoDS_Edge: ...

class BRepOffsetAPI_MakeDraft(BRepBuilderAPI_MakeShape):
	def __init__(self, Shape: TopoDS_Shape, Dir: gp_Dir, Angle: float) -> None: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	@overload
	def Perform(self, LengthMax: float) -> None: ...
	@overload
	def Perform(self, Surface: Geom_Surface, KeepInsideSurface: Optional[bool] = True) -> None: ...
	@overload
	def Perform(self, StopShape: TopoDS_Shape, KeepOutSide: Optional[bool] = True) -> None: ...
	def SetDraft(self, IsInternal: Optional[bool] = False) -> None: ...
	def SetOptions(self, Style: Optional[BRepBuilderAPI_TransitionMode] = BRepBuilderAPI_RightCorner, AngleMin: Optional[float] = 0.01, AngleMax: Optional[float] = 3.0) -> None: ...
	def Shell(self) -> TopoDS_Shell: ...

class BRepOffsetAPI_MakeEvolved(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theSpine: TopoDS_Shape, theProfile: TopoDS_Wire, theJoinType: Optional[GeomAbs_JoinType] = GeomAbs_Arc, theIsAxeProf: Optional[bool] = True, theIsSolid: Optional[bool] = False, theIsProfOnSpine: Optional[bool] = False, theTol: Optional[float] = 0.0000001, theIsVolume: Optional[bool] = False, theRunInParallel: Optional[bool] = False) -> None: ...
	def Bottom(self) -> TopoDS_Shape: ...
	def Build(self) -> None: ...
	def Evolved(self) -> BRepFill_Evolved: ...
	def GeneratedShapes(self, SpineShape: TopoDS_Shape, ProfShape: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def Top(self) -> TopoDS_Shape: ...

class BRepOffsetAPI_MakeFilling(BRepBuilderAPI_MakeShape):
	def __init__(self, Degree: Optional[int] = 3, NbPtsOnCur: Optional[int] = 15, NbIter: Optional[int] = 2, Anisotropie: Optional[bool] = False, Tol2d: Optional[float] = 0.00001, Tol3d: Optional[float] = 0.0001, TolAng: Optional[float] = 0.01, TolCurv: Optional[float] = 0.1, MaxDeg: Optional[int] = 8, MaxSegments: Optional[int] = 9) -> None: ...
	@overload
	def Add(self, Constr: TopoDS_Edge, Order: GeomAbs_Shape, IsBound: Optional[bool] = True) -> int: ...
	@overload
	def Add(self, Constr: TopoDS_Edge, Support: TopoDS_Face, Order: GeomAbs_Shape, IsBound: Optional[bool] = True) -> int: ...
	@overload
	def Add(self, Support: TopoDS_Face, Order: GeomAbs_Shape) -> int: ...
	@overload
	def Add(self, Point: gp_Pnt) -> int: ...
	@overload
	def Add(self, U: float, V: float, Support: TopoDS_Face, Order: GeomAbs_Shape) -> int: ...
	def Build(self) -> None: ...
	@overload
	def G0Error(self) -> float: ...
	@overload
	def G0Error(self, Index: int) -> float: ...
	@overload
	def G1Error(self) -> float: ...
	@overload
	def G1Error(self, Index: int) -> float: ...
	@overload
	def G2Error(self) -> float: ...
	@overload
	def G2Error(self, Index: int) -> float: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def IsDone(self) -> bool: ...
	def LoadInitSurface(self, Surf: TopoDS_Face) -> None: ...
	def SetApproxParam(self, MaxDeg: Optional[int] = 8, MaxSegments: Optional[int] = 9) -> None: ...
	def SetConstrParam(self, Tol2d: Optional[float] = 0.00001, Tol3d: Optional[float] = 0.0001, TolAng: Optional[float] = 0.01, TolCurv: Optional[float] = 0.1) -> None: ...
	def SetResolParam(self, Degree: Optional[int] = 3, NbPtsOnCur: Optional[int] = 15, NbIter: Optional[int] = 2, Anisotropie: Optional[bool] = False) -> None: ...

class BRepOffsetAPI_MakeOffset(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Spine: TopoDS_Face, Join: Optional[GeomAbs_JoinType] = GeomAbs_Arc, IsOpenResult: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Spine: TopoDS_Wire, Join: Optional[GeomAbs_JoinType] = GeomAbs_Arc, IsOpenResult: Optional[bool] = False) -> None: ...
	def AddWire(self, Spine: TopoDS_Wire) -> None: ...
	def Build(self) -> None: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	@overload
	def Init(self, Spine: TopoDS_Face, Join: Optional[GeomAbs_JoinType] = GeomAbs_Arc, IsOpenResult: Optional[bool] = False) -> None: ...
	@overload
	def Init(self, Join: Optional[GeomAbs_JoinType] = GeomAbs_Arc, IsOpenResult: Optional[bool] = False) -> None: ...
	def Perform(self, Offset: float, Alt: Optional[float] = 0.0) -> None: ...

class BRepOffsetAPI_MakeOffsetShape(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, Offset: float, Tol: float, Mode: Optional[BRepOffset_Mode] = BRepOffset_Skin, Intersection: Optional[bool] = False, SelfInter: Optional[bool] = False, Join: Optional[GeomAbs_JoinType] = GeomAbs_Arc, RemoveIntEdges: Optional[bool] = False) -> None: ...
	def Build(self) -> None: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def GetJoinType(self) -> GeomAbs_JoinType: ...
	def IsDeleted(self, S: TopoDS_Shape) -> bool: ...
	def MakeOffset(self) -> BRepOffset_MakeOffset: ...
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def PerformByJoin(self, S: TopoDS_Shape, Offset: float, Tol: float, Mode: Optional[BRepOffset_Mode] = BRepOffset_Skin, Intersection: Optional[bool] = False, SelfInter: Optional[bool] = False, Join: Optional[GeomAbs_JoinType] = GeomAbs_Arc, RemoveIntEdges: Optional[bool] = False) -> None: ...
	def PerformBySimple(self, theS: TopoDS_Shape, theOffsetValue: float) -> None: ...

class BRepOffsetAPI_MakePipe(BRepPrimAPI_MakeSweep):
	@overload
	def __init__(self, Spine: TopoDS_Wire, Profile: TopoDS_Shape) -> None: ...
	@overload
	def __init__(self, Spine: TopoDS_Wire, Profile: TopoDS_Shape, aMode: GeomFill_Trihedron, ForceApproxC1: Optional[bool] = False) -> None: ...
	def Build(self) -> None: ...
	def ErrorOnSurface(self) -> float: ...
	def FirstShape(self) -> TopoDS_Shape: ...
	@overload
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	@overload
	def Generated(self, SSpine: TopoDS_Shape, SProfile: TopoDS_Shape) -> TopoDS_Shape: ...
	def LastShape(self) -> TopoDS_Shape: ...
	def Pipe(self) -> BRepFill_Pipe: ...

class BRepOffsetAPI_MakePipeShell(BRepPrimAPI_MakeSweep):
	def __init__(self, Spine: TopoDS_Wire) -> None: ...
	@overload
	def Add(self, Profile: TopoDS_Shape, WithContact: Optional[bool] = False, WithCorrection: Optional[bool] = False) -> None: ...
	@overload
	def Add(self, Profile: TopoDS_Shape, Location: TopoDS_Vertex, WithContact: Optional[bool] = False, WithCorrection: Optional[bool] = False) -> None: ...
	def Build(self) -> None: ...
	def Delete(self, Profile: TopoDS_Shape) -> None: ...
	def ErrorOnSurface(self) -> float: ...
	def FirstShape(self) -> TopoDS_Shape: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def GetStatus(self) -> BRepBuilderAPI_PipeError: ...
	def IsReady(self) -> bool: ...
	def LastShape(self) -> TopoDS_Shape: ...
	def MakeSolid(self) -> bool: ...
	def Profiles(self, theProfiles: TopTools_ListOfShape) -> None: ...
	def SetDiscreteMode(self) -> None: ...
	def SetForceApproxC1(self, ForceApproxC1: bool) -> None: ...
	@overload
	def SetLaw(self, Profile: TopoDS_Shape, L: Law_Function, WithContact: Optional[bool] = False, WithCorrection: Optional[bool] = False) -> None: ...
	@overload
	def SetLaw(self, Profile: TopoDS_Shape, L: Law_Function, Location: TopoDS_Vertex, WithContact: Optional[bool] = False, WithCorrection: Optional[bool] = False) -> None: ...
	def SetMaxDegree(self, NewMaxDegree: int) -> None: ...
	def SetMaxSegments(self, NewMaxSegments: int) -> None: ...
	@overload
	def SetMode(self, IsFrenet: Optional[bool] = False) -> None: ...
	@overload
	def SetMode(self, Axe: gp_Ax2) -> None: ...
	@overload
	def SetMode(self, BiNormal: gp_Dir) -> None: ...
	@overload
	def SetMode(self, SpineSupport: TopoDS_Shape) -> bool: ...
	@overload
	def SetMode(self, AuxiliarySpine: TopoDS_Wire, CurvilinearEquivalence: bool, KeepContact: Optional[BRepFill_TypeOfContact] = BRepFill_NoContact) -> None: ...
	def SetTolerance(self, Tol3d: Optional[float] = 1.0e-4, BoundTol: Optional[float] = 1.0e-4, TolAngular: Optional[float] = 1.0e-2) -> None: ...
	def SetTransitionMode(self, Mode: Optional[BRepBuilderAPI_TransitionMode] = BRepBuilderAPI_Transformed) -> None: ...
	def Simulate(self, NumberOfSection: int, Result: TopTools_ListOfShape) -> None: ...
	def Spine(self) -> TopoDS_Wire: ...

class BRepOffsetAPI_MiddlePath(BRepBuilderAPI_MakeShape):
	def __init__(self, aShape: TopoDS_Shape, StartShape: TopoDS_Shape, EndShape: TopoDS_Shape) -> None: ...
	def Build(self) -> None: ...

class BRepOffsetAPI_NormalProjection(BRepBuilderAPI_MakeShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape) -> None: ...
	def Add(self, ToProj: TopoDS_Shape) -> None: ...
	def Ancestor(self, E: TopoDS_Edge) -> TopoDS_Shape: ...
	def Build(self) -> None: ...
	def BuildWire(self, Liste: TopTools_ListOfShape) -> bool: ...
	def Compute3d(self, With3d: Optional[bool] = True) -> None: ...
	def Couple(self, E: TopoDS_Edge) -> TopoDS_Shape: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def Init(self, S: TopoDS_Shape) -> None: ...
	def IsDone(self) -> bool: ...
	def Projection(self) -> TopoDS_Shape: ...
	def SetLimit(self, FaceBoundaries: Optional[bool] = True) -> None: ...
	def SetMaxDistance(self, MaxDist: float) -> None: ...
	def SetParams(self, Tol3D: float, Tol2D: float, InternalContinuity: GeomAbs_Shape, MaxDegree: int, MaxSeg: int) -> None: ...

class BRepOffsetAPI_ThruSections(BRepBuilderAPI_MakeShape):
	def __init__(self, isSolid: Optional[bool] = False, ruled: Optional[bool] = False, pres3d: Optional[float] = 1.0e-06) -> None: ...
	def AddVertex(self, aVertex: TopoDS_Vertex) -> None: ...
	def AddWire(self, wire: TopoDS_Wire) -> None: ...
	def Build(self) -> None: ...
	def CheckCompatibility(self, check: Optional[bool] = True) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def CriteriumWeight(self) -> Tuple[float, float, float]: ...
	def FirstShape(self) -> TopoDS_Shape: ...
	def Generated(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def GeneratedFace(self, Edge: TopoDS_Shape) -> TopoDS_Shape: ...
	def Init(self, isSolid: Optional[bool] = False, ruled: Optional[bool] = False, pres3d: Optional[float] = 1.0e-06) -> None: ...
	def LastShape(self) -> TopoDS_Shape: ...
	def MaxDegree(self) -> int: ...
	def ParType(self) -> Approx_ParametrizationType: ...
	def SetContinuity(self, C: GeomAbs_Shape) -> None: ...
	def SetCriteriumWeight(self, W1: float, W2: float, W3: float) -> None: ...
	def SetMaxDegree(self, MaxDeg: int) -> None: ...
	def SetParType(self, ParType: Approx_ParametrizationType) -> None: ...
	def SetSmoothing(self, UseSmoothing: bool) -> None: ...
	def UseSmoothing(self) -> bool: ...
	def Wires(self) -> TopTools_ListOfShape: ...

class BRepOffsetAPI_MakeThickSolid(BRepOffsetAPI_MakeOffsetShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, ClosingFaces: TopTools_ListOfShape, Offset: float, Tol: float, Mode: Optional[BRepOffset_Mode] = BRepOffset_Skin, Intersection: Optional[bool] = False, SelfInter: Optional[bool] = False, Join: Optional[GeomAbs_JoinType] = GeomAbs_Arc, RemoveIntEdges: Optional[bool] = False) -> None: ...
	def Build(self) -> None: ...
	def MakeThickSolidByJoin(self, S: TopoDS_Shape, ClosingFaces: TopTools_ListOfShape, Offset: float, Tol: float, Mode: Optional[BRepOffset_Mode] = BRepOffset_Skin, Intersection: Optional[bool] = False, SelfInter: Optional[bool] = False, Join: Optional[GeomAbs_JoinType] = GeomAbs_Arc, RemoveIntEdges: Optional[bool] = False) -> None: ...
	def MakeThickSolidBySimple(self, theS: TopoDS_Shape, theOffsetValue: float) -> None: ...
	def Modified(self, S: TopoDS_Shape) -> TopTools_ListOfShape: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *

#the following typedef cannot be wrapped as is
BVH_Array2d = NewType('BVH_Array2d', Any)
#the following typedef cannot be wrapped as is
BVH_Array2f = NewType('BVH_Array2f', Any)
#the following typedef cannot be wrapped as is
BVH_Array2i = NewType('BVH_Array2i', Any)
#the following typedef cannot be wrapped as is
BVH_Array3d = NewType('BVH_Array3d', Any)
#the following typedef cannot be wrapped as is
BVH_Array3f = NewType('BVH_Array3f', Any)
#the following typedef cannot be wrapped as is
BVH_Array3i = NewType('BVH_Array3i', Any)
#the following typedef cannot be wrapped as is
BVH_Array4d = NewType('BVH_Array4d', Any)
#the following typedef cannot be wrapped as is
BVH_Array4f = NewType('BVH_Array4f', Any)
#the following typedef cannot be wrapped as is
BVH_Array4i = NewType('BVH_Array4i', Any)
#the following typedef cannot be wrapped as is
BVH_EncodedLink = NewType('BVH_EncodedLink', Any)
#the following typedef cannot be wrapped as is
BVH_Mat4d = NewType('BVH_Mat4d', Any)
#the following typedef cannot be wrapped as is
BVH_Mat4f = NewType('BVH_Mat4f', Any)
#the following typedef cannot be wrapped as is
BVH_PrimitiveSet3d = NewType('BVH_PrimitiveSet3d', Any)
#the following typedef cannot be wrapped as is
BVH_Vec2d = NewType('BVH_Vec2d', Any)
#the following typedef cannot be wrapped as is
BVH_Vec2f = NewType('BVH_Vec2f', Any)
#the following typedef cannot be wrapped as is
BVH_Vec2i = NewType('BVH_Vec2i', Any)
#the following typedef cannot be wrapped as is
BVH_Vec3d = NewType('BVH_Vec3d', Any)
#the following typedef cannot be wrapped as is
BVH_Vec3f = NewType('BVH_Vec3f', Any)
#the following typedef cannot be wrapped as is
BVH_Vec3i = NewType('BVH_Vec3i', Any)
#the following typedef cannot be wrapped as is
BVH_Vec4d = NewType('BVH_Vec4d', Any)
#the following typedef cannot be wrapped as is
BVH_Vec4f = NewType('BVH_Vec4f', Any)
#the following typedef cannot be wrapped as is
BVH_Vec4i = NewType('BVH_Vec4i', Any)

class BVH_AxisSelector:
	@staticmethod
	def MainAxis(theSize: BVH_VecNt) -> int: ...

class BVH_BaseBox:
	pass

class BVH_Tree():
	def __init__(self) -> None: ...
	@overload
	def AddInnerNode(self, theMinPoint: BVH_VecNt, theMaxPoint: BVH_VecNt, theLftChild: int, theRghChild: int) -> False: ...
	@overload
	def AddInnerNode(self, theLftChild: int, theRghChild: int) -> False: ...
	@overload
	def AddLeafNode(self, theMinPoint: BVH_VecNt, theMaxPoint: BVH_VecNt, theBegElem: int, theEndElem: int) -> False: ...
	@overload
	def AddLeafNode(self, theBegElem: int, theEndElem: int) -> False: ...
	def Clear(self) -> None: ...
	def CollapseToQuadTree(self) -> False: ...
	def EstimateSAH(self) -> False: ...
	def Reserve(self, theNbNodes: int) -> None: ...
	def SetInner(self, theNodeIndex: int) -> None: ...
	def SetOuter(self, theNodeIndex: int) -> None: ...

class BVH_Tree():
	def __init__(self) -> None: ...

#classnotwrapped
class BVH_Tools: ...

#classnotwrapped
class BVH_BuildTool: ...

#classnotwrapped
class BVH_BuildThread: ...

#classnotwrapped
class BVH_Sorter: ...

#classnotwrapped
class BVH_ObjectSet: ...

#classnotwrapped
class BVH_BaseBox: ...

#classnotwrapped
class BVH_Box: ...

#classnotwrapped
class CenterAxis: ...

#classnotwrapped
class SurfaceCalculator: ...

#classnotwrapped
class BoxMinMax: ...

#classnotwrapped
class BVH_Distance: ...

#classnotwrapped
class BVH_ObjectTransient: ...

#classnotwrapped
class BVH_Object: ...

#classnotwrapped
class BVH_QuickSorter: ...

#classnotwrapped
class BVH_Set: ...

#classnotwrapped
class BVH_SpatialMedianBuilder: ...

#classnotwrapped
class BVH_Tree: ...

#classnotwrapped
class BVH_PrimitiveSet: ...

#classnotwrapped
class BVH_BuildQueue: ...

#classnotwrapped
class BVH_BuilderTransient: ...

#classnotwrapped
class BVH_Builder: ...

#classnotwrapped
class BVH_Properties: ...

#classnotwrapped
class BVH_Transform: ...

#classnotwrapped
class MatrixOp: ...

#classnotwrapped
class UnitVector: ...

#classnotwrapped
class BVH_RadixSorter: ...

#classnotwrapped
class BitPredicate: ...

#classnotwrapped
class BitComparator: ...

#classnotwrapped
class RadixSorter: ...

#classnotwrapped
class VectorType: ...

#classnotwrapped
class MatrixType: ...

#classnotwrapped
class ArrayType: ...

#classnotwrapped
class VecComp: ...

#classnotwrapped
class Array: ...

#classnotwrapped
class BVH_Triangulation: ...

#classnotwrapped
class BVH_PairDistance: ...

#classnotwrapped
class BVH_TreeBaseTransient: ...

#classnotwrapped
class BVH_TreeBase: ...

#classnotwrapped
class BVH_QuadTree: ...

#classnotwrapped
class BVH_BinaryTree: ...

#classnotwrapped
class BVH_SweepPlaneBuilder: ...

#classnotwrapped
class BVH_BaseTraverse: ...

#classnotwrapped
class BVH_Traverse: ...

#classnotwrapped
class BVH_PairTraverse: ...

#classnotwrapped
class BVH_BoxSet: ...

#classnotwrapped
class BVH_Ray: ...

#classnotwrapped
class BVH_Geometry: ...

#classnotwrapped
class BVH_QueueBuilder: ...

#classnotwrapped
class BVH_DistanceField: ...

#classnotwrapped
class BVH_LinearBuilder: ...

#classnotwrapped
class BoundData: ...

#classnotwrapped
class UpdateBoundTask: ...

#classnotwrapped
class BVH_Bin: ...

#classnotwrapped
class BVH_BinnedBuilder: ...

#classnotwrapped
class BVH_AxisSelector: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
TransferBRep module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_transferbrep.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TransferBRep
else:
    import _TransferBRep

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TransferBRep.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _TransferBRep.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TransferBRep.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _TransferBRep.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _TransferBRep.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _TransferBRep.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _TransferBRep.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _TransferBRep.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _TransferBRep.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _TransferBRep.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TransferBRep.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _TransferBRep.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _TransferBRep.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TransferBRep.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _TransferBRep.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _TransferBRep.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _TransferBRep.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TransferBRep:
_TransferBRep.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _TransferBRep.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.TopTools
import OCC.Core.Transfer

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_TransferBRep_BinderOfShape_Create() -> "opencascade::handle< TransferBRep_BinderOfShape >":
    return _TransferBRep.Handle_TransferBRep_BinderOfShape_Create()

def Handle_TransferBRep_BinderOfShape_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TransferBRep_BinderOfShape >":
    return _TransferBRep.Handle_TransferBRep_BinderOfShape_DownCast(t)

def Handle_TransferBRep_BinderOfShape_IsNull(t: "opencascade::handle< TransferBRep_BinderOfShape > const &") -> "bool":
    return _TransferBRep.Handle_TransferBRep_BinderOfShape_IsNull(t)

def Handle_TransferBRep_OrientedShapeMapper_Create() -> "opencascade::handle< TransferBRep_OrientedShapeMapper >":
    return _TransferBRep.Handle_TransferBRep_OrientedShapeMapper_Create()

def Handle_TransferBRep_OrientedShapeMapper_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TransferBRep_OrientedShapeMapper >":
    return _TransferBRep.Handle_TransferBRep_OrientedShapeMapper_DownCast(t)

def Handle_TransferBRep_OrientedShapeMapper_IsNull(t: "opencascade::handle< TransferBRep_OrientedShapeMapper > const &") -> "bool":
    return _TransferBRep.Handle_TransferBRep_OrientedShapeMapper_IsNull(t)

def Handle_TransferBRep_ShapeListBinder_Create() -> "opencascade::handle< TransferBRep_ShapeListBinder >":
    return _TransferBRep.Handle_TransferBRep_ShapeListBinder_Create()

def Handle_TransferBRep_ShapeListBinder_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TransferBRep_ShapeListBinder >":
    return _TransferBRep.Handle_TransferBRep_ShapeListBinder_DownCast(t)

def Handle_TransferBRep_ShapeListBinder_IsNull(t: "opencascade::handle< TransferBRep_ShapeListBinder > const &") -> "bool":
    return _TransferBRep.Handle_TransferBRep_ShapeListBinder_IsNull(t)

def Handle_TransferBRep_ShapeMapper_Create() -> "opencascade::handle< TransferBRep_ShapeMapper >":
    return _TransferBRep.Handle_TransferBRep_ShapeMapper_Create()

def Handle_TransferBRep_ShapeMapper_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TransferBRep_ShapeMapper >":
    return _TransferBRep.Handle_TransferBRep_ShapeMapper_DownCast(t)

def Handle_TransferBRep_ShapeMapper_IsNull(t: "opencascade::handle< TransferBRep_ShapeMapper > const &") -> "bool":
    return _TransferBRep.Handle_TransferBRep_ShapeMapper_IsNull(t)

def Handle_TransferBRep_TransferResultInfo_Create() -> "opencascade::handle< TransferBRep_TransferResultInfo >":
    return _TransferBRep.Handle_TransferBRep_TransferResultInfo_Create()

def Handle_TransferBRep_TransferResultInfo_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TransferBRep_TransferResultInfo >":
    return _TransferBRep.Handle_TransferBRep_TransferResultInfo_DownCast(t)

def Handle_TransferBRep_TransferResultInfo_IsNull(t: "opencascade::handle< TransferBRep_TransferResultInfo > const &") -> "bool":
    return _TransferBRep.Handle_TransferBRep_TransferResultInfo_IsNull(t)

def Handle_TransferBRep_ShapeBinder_Create() -> "opencascade::handle< TransferBRep_ShapeBinder >":
    return _TransferBRep.Handle_TransferBRep_ShapeBinder_Create()

def Handle_TransferBRep_ShapeBinder_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TransferBRep_ShapeBinder >":
    return _TransferBRep.Handle_TransferBRep_ShapeBinder_DownCast(t)

def Handle_TransferBRep_ShapeBinder_IsNull(t: "opencascade::handle< TransferBRep_ShapeBinder > const &") -> "bool":
    return _TransferBRep.Handle_TransferBRep_ShapeBinder_IsNull(t)

def Handle_TransferBRep_HSequenceOfTransferResultInfo_Create() -> "opencascade::handle< TransferBRep_HSequenceOfTransferResultInfo >":
    return _TransferBRep.Handle_TransferBRep_HSequenceOfTransferResultInfo_Create()

def Handle_TransferBRep_HSequenceOfTransferResultInfo_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< TransferBRep_HSequenceOfTransferResultInfo >":
    return _TransferBRep.Handle_TransferBRep_HSequenceOfTransferResultInfo_DownCast(t)

def Handle_TransferBRep_HSequenceOfTransferResultInfo_IsNull(t: "opencascade::handle< TransferBRep_HSequenceOfTransferResultInfo > const &") -> "bool":
    return _TransferBRep.Handle_TransferBRep_HSequenceOfTransferResultInfo_IsNull(t)
class TransferBRep_SequenceOfTransferResultInfo(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< TransferBRep_TransferResultInfo > >::iterator":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< TransferBRep_TransferResultInfo > >::iterator":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< TransferBRep_TransferResultInfo > >::const_iterator":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< TransferBRep_TransferResultInfo > >::const_iterator":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_cend(self)

    def __init__(self, *args):
        _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_swiginit(self, _TransferBRep.new_TransferBRep_SequenceOfTransferResultInfo(*args))

    def Size(self) -> "Standard_Integer":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Size(self)

    def Length(self) -> "Standard_Integer":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_IsEmpty(self)

    def Reverse(self) -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Clear(self, theAllocator)

    def Assign(self, theOther: "TransferBRep_SequenceOfTransferResultInfo") -> "NCollection_Sequence< opencascade::handle< TransferBRep_TransferResultInfo > > &":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Assign(self, theOther)

    def Set(self, theOther: "TransferBRep_SequenceOfTransferResultInfo") -> "NCollection_Sequence< opencascade::handle< TransferBRep_TransferResultInfo > > &":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "TransferBRep_SequenceOfTransferResultInfo") -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< TransferBRep_TransferResultInfo > const &":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_First(self)

    def ChangeFirst(self) -> "opencascade::handle< TransferBRep_TransferResultInfo > &":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< TransferBRep_TransferResultInfo > const &":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Last(self)

    def ChangeLast(self) -> "opencascade::handle< TransferBRep_TransferResultInfo > &":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< TransferBRep_TransferResultInfo > const &":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< TransferBRep_TransferResultInfo > &":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< TransferBRep_TransferResultInfo > &":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< TransferBRep_TransferResultInfo > const &") -> "void":
        return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _TransferBRep.delete_TransferBRep_SequenceOfTransferResultInfo

    def __len__(self):
        return self.Size()


# Register TransferBRep_SequenceOfTransferResultInfo in _TransferBRep:
_TransferBRep.TransferBRep_SequenceOfTransferResultInfo_swigregister(TransferBRep_SequenceOfTransferResultInfo)

def TransferBRep_SequenceOfTransferResultInfo_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _TransferBRep.TransferBRep_SequenceOfTransferResultInfo_delNode(theNode, theAl)

class transferbrep(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def CheckObject(*args) -> "Interface_CheckIterator":
        r"""
        Returns the check-list bound to a given object, generally none (if ok) or one check. <obj> can be, either a true transient object or entity, or a shapemapper, in that case the shape is considered.

        Parameters
        ----------
        chl: Interface_CheckIterator
        obj: Standard_Transient

        Returns
        -------
        Interface_CheckIterator

        """
        return _TransferBRep.transferbrep_CheckObject(*args)

    @staticmethod
    def Checked(*args) -> "opencascade::handle< TColStd_HSequenceOfTransient >":
        r"""
        Returns the list of objects to which a non-empty check is bound in a check-list. objects are transients, they can then be either imagine objects entities for an interface norm. <alsoshapes> commands shapes to be returned too (as shapemapper), see also checkedshapes.

        Parameters
        ----------
        chl: Interface_CheckIterator
        alsoshapes: bool,optional
        	default value is Standard_False

        Returns
        -------
        opencascade::handle<TColStd_HSequenceOfTransient>

        """
        return _TransferBRep.transferbrep_Checked(*args)

    @staticmethod
    def CheckedShapes(*args) -> "opencascade::handle< TopTools_HSequenceOfShape >":
        r"""
        Returns the list of shapes to which a non-empty check is bound in a check-list.

        Parameters
        ----------
        chl: Interface_CheckIterator

        Returns
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        """
        return _TransferBRep.transferbrep_CheckedShapes(*args)

    @staticmethod
    def PrintResultInfo(*args) -> "void":
        r"""
        Prints the results of transfer to given priner with given header.

        Parameters
        ----------
        Printer: Message_Printer
        Header: Message_Msg
        ResultInfo: TransferBRep_TransferResultInfo
        printEmpty: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _TransferBRep.transferbrep_PrintResultInfo(*args)

    @staticmethod
    def ResultCheckList(*args) -> "Interface_CheckIterator":
        r"""
        Takes a starting checkiterator which brings checks bound with starting objects (shapes, transient from an imagine appli ...) and converts it to a checkiterator in which checks are bound with results in an interfacemodel mapping is recorded in the finderprocess starting objects for which no individual result is recorded remain in their state.

        Parameters
        ----------
        chl: Interface_CheckIterator
        FP: Transfer_FinderProcess
        model: Interface_InterfaceModel

        Returns
        -------
        Interface_CheckIterator

        """
        return _TransferBRep.transferbrep_ResultCheckList(*args)

    @staticmethod
    def ResultFromShape(*args) -> "opencascade::handle< Transfer_Binder >":
        r"""
        Returns the result (as a binder) attached to a given shape null if none.

        Parameters
        ----------
        FP: Transfer_FinderProcess
        shape: TopoDS_Shape

        Returns
        -------
        opencascade::handle<Transfer_Binder>

        """
        return _TransferBRep.transferbrep_ResultFromShape(*args)

    @staticmethod
    def SetShapeResult(*args) -> "void":
        r"""
        Sets a shape as a result for a starting entity <ent> (reverse of shaperesult) it simply creates a shapebinder then binds it to the entity.

        Parameters
        ----------
        TP: Transfer_TransientProcess
        ent: Standard_Transient
        result: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TransferBRep.transferbrep_SetShapeResult(*args)

    @staticmethod
    def SetTransientFromShape(*args) -> "void":
        r"""
        Binds a transient result to a shape in a finderprocess (as first result if multiple : does not add it to existing one).

        Parameters
        ----------
        FP: Transfer_FinderProcess
        shape: TopoDS_Shape
        result: Standard_Transient

        Returns
        -------
        None

        """
        return _TransferBRep.transferbrep_SetTransientFromShape(*args)

    @staticmethod
    def ShapeMapper(*args) -> "opencascade::handle< TransferBRep_ShapeMapper >":
        r"""
        Returns a shapemapper for a given shape (location included) either <shape> is already mapped, then its mapper is returned or it is not, then a new one is created then returned, but it is not mapped here (use bind or findelsebind to do this).

        Parameters
        ----------
        FP: Transfer_FinderProcess
        shape: TopoDS_Shape

        Returns
        -------
        opencascade::handle<TransferBRep_ShapeMapper>

        """
        return _TransferBRep.transferbrep_ShapeMapper(*args)

    @staticmethod
    def ShapeResult(*args) -> "TopoDS_Shape":
        r"""
        Get the shape recorded in a binder if the binder brings a multiple result, search for the shape.

        Parameters
        ----------
        binder: Transfer_Binder

        Returns
        -------
        TopoDS_Shape
        Get the shape recorded in a transientprocess as result of the transfer of an entity. i.e. in the binder bound to that entity if no result or result not a single shape, returns a null shape.

        Parameters
        ----------
        TP: Transfer_TransientProcess
        ent: Standard_Transient

        Returns
        -------
        TopoDS_Shape

        """
        return _TransferBRep.transferbrep_ShapeResult(*args)

    @staticmethod
    def ShapeState(*args) -> "TopAbs_Orientation":
        r"""
        Returns a status regarding a shape in a finderprocess - forward means bound with same orientation - reversed means bound with reverse orientation - external means not bound - internal is not used.

        Parameters
        ----------
        FP: Transfer_FinderProcess
        shape: TopoDS_Shape

        Returns
        -------
        TopAbs_Orientation

        """
        return _TransferBRep.transferbrep_ShapeState(*args)

    @staticmethod
    def Shapes(*args) -> "opencascade::handle< TopTools_HSequenceOfShape >":
        r"""
        Gets the shapes recorded in a transientprocess as result of a transfer, considers roots only or all results according <rootsonly>, returns them as a hsequence.

        Parameters
        ----------
        TP: Transfer_TransientProcess
        rootsonly: bool,optional
        	default value is Standard_True

        Returns
        -------
        opencascade::handle<TopTools_HSequenceOfShape>
        Gets the shapes recorded in a transientprocess as result of a transfer, for a given list of starting entities, returns the shapes as a hsequence.

        Parameters
        ----------
        TP: Transfer_TransientProcess
        list: TColStd_HSequenceOfTransient

        Returns
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        """
        return _TransferBRep.transferbrep_Shapes(*args)

    @staticmethod
    def TransferResultInfo(*args) -> "void":
        r"""
        Fills sequence of transferresultinfo for each type of entity given in the entitytypes (entity are given as objects). method iskind applied to the entities in tp is used to compare with entities in entitytypes. topabs_shapeenum).

        Parameters
        ----------
        TP: Transfer_TransientProcess
        EntityTypes: TColStd_HSequenceOfTransient
        InfoSeq: TransferBRep_HSequenceOfTransferResultInfo

        Returns
        -------
        None
        Fills sequence of transferresultinfo for each type of shape given in the shapetypes (which are in fact considered as topabs_shapeenum). the finders in the fp are considered as shapemappers.

        Parameters
        ----------
        FP: Transfer_FinderProcess
        ShapeTypes: TColStd_HSequenceOfInteger
        InfoSeq: TransferBRep_HSequenceOfTransferResultInfo

        Returns
        -------
        None

        """
        return _TransferBRep.transferbrep_TransferResultInfo(*args)

    @staticmethod
    def TransientFromShape(*args) -> "opencascade::handle< Standard_Transient >":
        r"""
        Returns the result as pure transient attached to a shape first one if multiple result.

        Parameters
        ----------
        FP: Transfer_FinderProcess
        shape: TopoDS_Shape

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _TransferBRep.transferbrep_TransientFromShape(*args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def BRepCheck(self):
    	pass


    def __init__(self):
        _TransferBRep.transferbrep_swiginit(self, _TransferBRep.new_transferbrep())
    __swig_destroy__ = _TransferBRep.delete_transferbrep

# Register transferbrep in _TransferBRep:
_TransferBRep.transferbrep_swigregister(transferbrep)

def transferbrep_CheckObject(*args) -> "Interface_CheckIterator":
    r"""
    Returns the check-list bound to a given object, generally none (if ok) or one check. <obj> can be, either a true transient object or entity, or a shapemapper, in that case the shape is considered.

    Parameters
    ----------
    chl: Interface_CheckIterator
    obj: Standard_Transient

    Returns
    -------
    Interface_CheckIterator

    """
    return _TransferBRep.transferbrep_CheckObject(*args)

def transferbrep_Checked(*args) -> "opencascade::handle< TColStd_HSequenceOfTransient >":
    r"""
    Returns the list of objects to which a non-empty check is bound in a check-list. objects are transients, they can then be either imagine objects entities for an interface norm. <alsoshapes> commands shapes to be returned too (as shapemapper), see also checkedshapes.

    Parameters
    ----------
    chl: Interface_CheckIterator
    alsoshapes: bool,optional
    	default value is Standard_False

    Returns
    -------
    opencascade::handle<TColStd_HSequenceOfTransient>

    """
    return _TransferBRep.transferbrep_Checked(*args)

def transferbrep_CheckedShapes(*args) -> "opencascade::handle< TopTools_HSequenceOfShape >":
    r"""
    Returns the list of shapes to which a non-empty check is bound in a check-list.

    Parameters
    ----------
    chl: Interface_CheckIterator

    Returns
    -------
    opencascade::handle<TopTools_HSequenceOfShape>

    """
    return _TransferBRep.transferbrep_CheckedShapes(*args)

def transferbrep_PrintResultInfo(*args) -> "void":
    r"""
    Prints the results of transfer to given priner with given header.

    Parameters
    ----------
    Printer: Message_Printer
    Header: Message_Msg
    ResultInfo: TransferBRep_TransferResultInfo
    printEmpty: bool,optional
    	default value is Standard_True

    Returns
    -------
    None

    """
    return _TransferBRep.transferbrep_PrintResultInfo(*args)

def transferbrep_ResultCheckList(*args) -> "Interface_CheckIterator":
    r"""
    Takes a starting checkiterator which brings checks bound with starting objects (shapes, transient from an imagine appli ...) and converts it to a checkiterator in which checks are bound with results in an interfacemodel mapping is recorded in the finderprocess starting objects for which no individual result is recorded remain in their state.

    Parameters
    ----------
    chl: Interface_CheckIterator
    FP: Transfer_FinderProcess
    model: Interface_InterfaceModel

    Returns
    -------
    Interface_CheckIterator

    """
    return _TransferBRep.transferbrep_ResultCheckList(*args)

def transferbrep_ResultFromShape(*args) -> "opencascade::handle< Transfer_Binder >":
    r"""
    Returns the result (as a binder) attached to a given shape null if none.

    Parameters
    ----------
    FP: Transfer_FinderProcess
    shape: TopoDS_Shape

    Returns
    -------
    opencascade::handle<Transfer_Binder>

    """
    return _TransferBRep.transferbrep_ResultFromShape(*args)

def transferbrep_SetShapeResult(*args) -> "void":
    r"""
    Sets a shape as a result for a starting entity <ent> (reverse of shaperesult) it simply creates a shapebinder then binds it to the entity.

    Parameters
    ----------
    TP: Transfer_TransientProcess
    ent: Standard_Transient
    result: TopoDS_Shape

    Returns
    -------
    None

    """
    return _TransferBRep.transferbrep_SetShapeResult(*args)

def transferbrep_SetTransientFromShape(*args) -> "void":
    r"""
    Binds a transient result to a shape in a finderprocess (as first result if multiple : does not add it to existing one).

    Parameters
    ----------
    FP: Transfer_FinderProcess
    shape: TopoDS_Shape
    result: Standard_Transient

    Returns
    -------
    None

    """
    return _TransferBRep.transferbrep_SetTransientFromShape(*args)

def transferbrep_ShapeMapper(*args) -> "opencascade::handle< TransferBRep_ShapeMapper >":
    r"""
    Returns a shapemapper for a given shape (location included) either <shape> is already mapped, then its mapper is returned or it is not, then a new one is created then returned, but it is not mapped here (use bind or findelsebind to do this).

    Parameters
    ----------
    FP: Transfer_FinderProcess
    shape: TopoDS_Shape

    Returns
    -------
    opencascade::handle<TransferBRep_ShapeMapper>

    """
    return _TransferBRep.transferbrep_ShapeMapper(*args)

def transferbrep_ShapeResult(*args) -> "TopoDS_Shape":
    r"""
    Get the shape recorded in a binder if the binder brings a multiple result, search for the shape.

    Parameters
    ----------
    binder: Transfer_Binder

    Returns
    -------
    TopoDS_Shape
    Get the shape recorded in a transientprocess as result of the transfer of an entity. i.e. in the binder bound to that entity if no result or result not a single shape, returns a null shape.

    Parameters
    ----------
    TP: Transfer_TransientProcess
    ent: Standard_Transient

    Returns
    -------
    TopoDS_Shape

    """
    return _TransferBRep.transferbrep_ShapeResult(*args)

def transferbrep_ShapeState(*args) -> "TopAbs_Orientation":
    r"""
    Returns a status regarding a shape in a finderprocess - forward means bound with same orientation - reversed means bound with reverse orientation - external means not bound - internal is not used.

    Parameters
    ----------
    FP: Transfer_FinderProcess
    shape: TopoDS_Shape

    Returns
    -------
    TopAbs_Orientation

    """
    return _TransferBRep.transferbrep_ShapeState(*args)

def transferbrep_Shapes(*args) -> "opencascade::handle< TopTools_HSequenceOfShape >":
    r"""
    Gets the shapes recorded in a transientprocess as result of a transfer, considers roots only or all results according <rootsonly>, returns them as a hsequence.

    Parameters
    ----------
    TP: Transfer_TransientProcess
    rootsonly: bool,optional
    	default value is Standard_True

    Returns
    -------
    opencascade::handle<TopTools_HSequenceOfShape>
    Gets the shapes recorded in a transientprocess as result of a transfer, for a given list of starting entities, returns the shapes as a hsequence.

    Parameters
    ----------
    TP: Transfer_TransientProcess
    list: TColStd_HSequenceOfTransient

    Returns
    -------
    opencascade::handle<TopTools_HSequenceOfShape>

    """
    return _TransferBRep.transferbrep_Shapes(*args)

def transferbrep_TransferResultInfo(*args) -> "void":
    r"""
    Fills sequence of transferresultinfo for each type of entity given in the entitytypes (entity are given as objects). method iskind applied to the entities in tp is used to compare with entities in entitytypes. topabs_shapeenum).

    Parameters
    ----------
    TP: Transfer_TransientProcess
    EntityTypes: TColStd_HSequenceOfTransient
    InfoSeq: TransferBRep_HSequenceOfTransferResultInfo

    Returns
    -------
    None
    Fills sequence of transferresultinfo for each type of shape given in the shapetypes (which are in fact considered as topabs_shapeenum). the finders in the fp are considered as shapemappers.

    Parameters
    ----------
    FP: Transfer_FinderProcess
    ShapeTypes: TColStd_HSequenceOfInteger
    InfoSeq: TransferBRep_HSequenceOfTransferResultInfo

    Returns
    -------
    None

    """
    return _TransferBRep.transferbrep_TransferResultInfo(*args)

def transferbrep_TransientFromShape(*args) -> "opencascade::handle< Standard_Transient >":
    r"""
    Returns the result as pure transient attached to a shape first one if multiple result.

    Parameters
    ----------
    FP: Transfer_FinderProcess
    shape: TopoDS_Shape

    Returns
    -------
    opencascade::handle<Standard_Transient>

    """
    return _TransferBRep.transferbrep_TransientFromShape(*args)

class TransferBRep_BinderOfShape(OCC.Core.Transfer.Transfer_Binder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Normal standard constructor, creates an empty binderofshape.

        Returns
        -------
        None
        Constructor which in the same time defines the result returns true if a starting object is bound with several results : here, returns allways false but it can have next results.

        Parameters
        ----------
        res: TopoDS_Shape

        Returns
        -------
        None

        """
        _TransferBRep.TransferBRep_BinderOfShape_swiginit(self, _TransferBRep.new_TransferBRep_BinderOfShape(*args))

    def CResult(self, *args) -> "TopoDS_Shape":
        r"""
        Returns the defined result, if there is one, and allows to change it (avoids result + setresult). admits that result can be not yet defined warning : a call to cresult causes result to be known as defined.

        Returns
        -------
        TopoDS_Shape

        """
        return _TransferBRep.TransferBRep_BinderOfShape_CResult(self, *args)

    def Result(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the defined result, if there is one.

        Returns
        -------
        TopoDS_Shape

        """
        return _TransferBRep.TransferBRep_BinderOfShape_Result(self, *args)

    def SetResult(self, *args) -> "void":
        r"""
        Defines the result.

        Parameters
        ----------
        res: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_BinderOfShape_SetResult(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TransferBRep_BinderOfShape_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TransferBRep.delete_TransferBRep_BinderOfShape

# Register TransferBRep_BinderOfShape in _TransferBRep:
_TransferBRep.TransferBRep_BinderOfShape_swigregister(TransferBRep_BinderOfShape)

class TransferBRep_OrientedShapeMapper(OCC.Core.Transfer.Transfer_Finder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a mapper with a value. this value can then not be changed. it is used by the hasher to compute the hashcode, which will then be stored for an immediate reading.

        Parameters
        ----------
        akey: TopoDS_Shape

        Returns
        -------
        None

        """
        _TransferBRep.TransferBRep_OrientedShapeMapper_swiginit(self, _TransferBRep.new_TransferBRep_OrientedShapeMapper(*args))

    def Value(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the contained value.

        Returns
        -------
        TopoDS_Shape

        """
        return _TransferBRep.TransferBRep_OrientedShapeMapper_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TransferBRep_OrientedShapeMapper_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TransferBRep.delete_TransferBRep_OrientedShapeMapper

# Register TransferBRep_OrientedShapeMapper in _TransferBRep:
_TransferBRep.TransferBRep_OrientedShapeMapper_swigregister(TransferBRep_OrientedShapeMapper)

class TransferBRep_Reader(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes a non-specialised reader. typically, for each norm or protocol, is will be required to define a specific create to load a file and transfer it.

        Returns
        -------
        None

        """
        _TransferBRep.TransferBRep_Reader_swiginit(self, _TransferBRep.new_TransferBRep_Reader(*args))

    def Actor(self, *args) -> "opencascade::handle< Transfer_ActorOfTransientProcess >":
        r"""
        Returns the recorded actor.

        Returns
        -------
        opencascade::handle<Transfer_ActorOfTransientProcess>

        """
        return _TransferBRep.TransferBRep_Reader_Actor(self, *args)

    def BeginTransfer(self, *args) -> "Standard_Boolean":
        r"""
        Initializes the reader for a transfer (one,roots, or list) also calls preparetransfer returns true when done, false if could not be done.

        Returns
        -------
        bool

        """
        return _TransferBRep.TransferBRep_Reader_BeginTransfer(self, *args)

    def CheckListModel(self, *args) -> "Interface_CheckIterator":
        r"""
        Checks the model (complete : syntax + semantic) and returns the produced check list.

        Returns
        -------
        Interface_CheckIterator

        """
        return _TransferBRep.TransferBRep_Reader_CheckListModel(self, *args)

    def CheckListResult(self, *args) -> "Interface_CheckIterator":
        r"""
        Checks the result of last transfer (individual or roots, no cumulation on several transfers) and returns the produced list.

        Returns
        -------
        Interface_CheckIterator

        """
        return _TransferBRep.TransferBRep_Reader_CheckListResult(self, *args)

    def CheckStatusModel(self, *args) -> "Standard_Boolean":
        r"""
        Checks the model. returns true if there is no fail at all (regardless warnings) if <withprint> is true, also sends checks on standard output.

        Parameters
        ----------
        withprint: bool

        Returns
        -------
        bool

        """
        return _TransferBRep.TransferBRep_Reader_CheckStatusModel(self, *args)

    def CheckStatusResult(self, *args) -> "Standard_Boolean":
        r"""
        Checks the result of last transfer (individual or roots, no cumulation on several transfers). returns true if no fail occured during transfer (queries the transientprocess).

        Parameters
        ----------
        withprints: bool

        Returns
        -------
        bool

        """
        return _TransferBRep.TransferBRep_Reader_CheckStatusResult(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        Clears the result and done status. but not the model.

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_Reader_Clear(self, *args)

    def EndTransfer(self, *args) -> "void":
        r"""
        Ebds a transfer (one, roots or list) by recording its result.

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_Reader_EndTransfer(self, *args)

    def FileNotFound(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if filestatus is for filenotfound.

        Returns
        -------
        bool

        """
        return _TransferBRep.TransferBRep_Reader_FileNotFound(self, *args)

    def FileStatus(self, *args) -> "Standard_Integer":
        r"""
        Returns the file status.

        Returns
        -------
        int

        """
        return _TransferBRep.TransferBRep_Reader_FileStatus(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the last transfer/transferroots was a success.

        Returns
        -------
        bool

        """
        return _TransferBRep.TransferBRep_Reader_IsDone(self, *args)

    def GetModeNewTransfer(self) -> "Standard_Boolean":
        r"""GetModeNewTransfer(TransferBRep_Reader self) -> Standard_Boolean"""
        return _TransferBRep.TransferBRep_Reader_GetModeNewTransfer(self)

    def SetModeNewTransfer(self, value: "Standard_Boolean") -> "void":
        r"""SetModeNewTransfer(TransferBRep_Reader self, Standard_Boolean value)"""
        return _TransferBRep.TransferBRep_Reader_SetModeNewTransfer(self, value)

    def Model(self, *args) -> "opencascade::handle< Interface_InterfaceModel >":
        r"""
        Returns the model to be worked on.

        Returns
        -------
        opencascade::handle<Interface_InterfaceModel>

        """
        return _TransferBRep.TransferBRep_Reader_Model(self, *args)

    def NbShapes(self, *args) -> "Standard_Integer":
        r"""
        Returns the count of produced shapes (roots).

        Returns
        -------
        int

        """
        return _TransferBRep.TransferBRep_Reader_NbShapes(self, *args)

    def NbTransients(self, *args) -> "Standard_Integer":
        r"""
        Returns the count of produced transient results (roots).

        Returns
        -------
        int

        """
        return _TransferBRep.TransferBRep_Reader_NbTransients(self, *args)

    def OneShape(self, *args) -> "TopoDS_Shape":
        r"""
        Returns a unique shape for the result : - a void shape (type = shape) if result is empty - a simple shape if result has only one : returns this one - a compound if result has more than one shape.

        Returns
        -------
        TopoDS_Shape

        """
        return _TransferBRep.TransferBRep_Reader_OneShape(self, *args)

    def PrepareTransfer(self, *args) -> "void":
        r"""
        Prepares the transfer. also can act on the actor or change the transientprocess if required. should not set the actor into the transientprocess, it is done by caller. the provided default does nothing.

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_Reader_PrepareTransfer(self, *args)

    def Protocol(self, *args) -> "opencascade::handle< Interface_Protocol >":
        r"""
        Returns the recorded protocol.

        Returns
        -------
        opencascade::handle<Interface_Protocol>

        """
        return _TransferBRep.TransferBRep_Reader_Protocol(self, *args)

    def SetActor(self, *args) -> "void":
        r"""
        Records the actor to be used for transfers.

        Parameters
        ----------
        actor: Transfer_ActorOfTransientProcess

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_Reader_SetActor(self, *args)

    def SetFileStatus(self, *args) -> "void":
        r"""
        Sets file status to be interpreted as follows : = 0 ok < 0 file not found > 0 read error, no model could be created.

        Parameters
        ----------
        status: int

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_Reader_SetFileStatus(self, *args)

    def SetModel(self, *args) -> "void":
        r"""
        Specifies a model to work on also clears the result and done status.

        Parameters
        ----------
        model: Interface_InterfaceModel

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_Reader_SetModel(self, *args)

    def SetProtocol(self, *args) -> "void":
        r"""
        Records the protocol to be used for read and transfer roots.

        Parameters
        ----------
        protocol: Interface_Protocol

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_Reader_SetProtocol(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns a shape given its rank, by default the first one.

        Parameters
        ----------
        num: int,optional
        	default value is 1

        Returns
        -------
        TopoDS_Shape

        """
        return _TransferBRep.TransferBRep_Reader_Shape(self, *args)

    def ShapeResult(self, *args) -> "TopoDS_Shape":
        r"""
        Returns a shape produced from a given entity (if it was individually transferred or if an intermediate result is known). if no shape is bound with <ent>, returns a null shape warning : runs on the last call to transfer,transferroots,transferlist.

        Parameters
        ----------
        ent: Standard_Transient

        Returns
        -------
        TopoDS_Shape

        """
        return _TransferBRep.TransferBRep_Reader_ShapeResult(self, *args)

    def Shapes(self, *args) -> "opencascade::handle< TopTools_HSequenceOfShape >":
        r"""
        Returns the complete list of produced shapes.

        Returns
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        """
        return _TransferBRep.TransferBRep_Reader_Shapes(self, *args)

    def SyntaxError(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if filestatus is for error during read (major error; for local error, see checkmodel).

        Returns
        -------
        bool

        """
        return _TransferBRep.TransferBRep_Reader_SyntaxError(self, *args)

    def Transfer(self, *args) -> "Standard_Boolean":
        r"""
        Transfers an entity given its rank in the model (root or not) returns true if it is recognized as geom-topol. (but it can have failed : see isdone).

        Parameters
        ----------
        num: int
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        bool

        """
        return _TransferBRep.TransferBRep_Reader_Transfer(self, *args)

    def TransferList(self, *args) -> "void":
        r"""
        Transfers a list of entities (only the ones also in the model) remark : former result is cleared.

        Parameters
        ----------
        list: TColStd_HSequenceOfTransient
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_Reader_TransferList(self, *args)

    def TransferRoots(self, *args) -> "void":
        r"""
        Transfers all root entities which are recognized as geom-topol the result will be a list of shapes. this method calls user redefinable preparetransfer remark : former result is cleared.

        Parameters
        ----------
        theProgress: Message_ProgressRange,optional
        	default value is Message_ProgressRange()

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_Reader_TransferRoots(self, *args)

    def Transient(self, *args) -> "opencascade::handle< Standard_Transient >":
        r"""
        Returns a transient root result, given its rank (by default the first one).

        Parameters
        ----------
        num: int,optional
        	default value is 1

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _TransferBRep.TransferBRep_Reader_Transient(self, *args)

    def TransientProcess(self, *args) -> "opencascade::handle< Transfer_TransientProcess >":
        r"""
        Returns the transientprocess. it records informations about the very last transfer done. null if no transfer yet done. can be used for queries more accurate than the default ones.

        Returns
        -------
        opencascade::handle<Transfer_TransientProcess>

        """
        return _TransferBRep.TransferBRep_Reader_TransientProcess(self, *args)

    def Transients(self, *args) -> "opencascade::handle< TColStd_HSequenceOfTransient >":
        r"""
        Returns the complete list of produced transient results.

        Returns
        -------
        opencascade::handle<TColStd_HSequenceOfTransient>

        """
        return _TransferBRep.TransferBRep_Reader_Transients(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TransferBRep.delete_TransferBRep_Reader

# Register TransferBRep_Reader in _TransferBRep:
_TransferBRep.TransferBRep_Reader_swigregister(TransferBRep_Reader)

class TransferBRep_ShapeInfo(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Type(*args) -> "opencascade::handle< Standard_Type >":
        r"""
        Returns the type attached to an object here, tshape (shape has no dynamic type).

        Parameters
        ----------
        ent: TopoDS_Shape

        Returns
        -------
        opencascade::handle<Standard_Type>

        """
        return _TransferBRep.TransferBRep_ShapeInfo_Type(*args)

    @staticmethod
    def TypeName(*args) -> "char const *":
        r"""
        Returns type name (string) here, the true name of the type of a shape.

        Parameters
        ----------
        ent: TopoDS_Shape

        Returns
        -------
        char *

        """
        return _TransferBRep.TransferBRep_ShapeInfo_TypeName(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TransferBRep.TransferBRep_ShapeInfo_swiginit(self, _TransferBRep.new_TransferBRep_ShapeInfo())
    __swig_destroy__ = _TransferBRep.delete_TransferBRep_ShapeInfo

# Register TransferBRep_ShapeInfo in _TransferBRep:
_TransferBRep.TransferBRep_ShapeInfo_swigregister(TransferBRep_ShapeInfo)

def TransferBRep_ShapeInfo_Type(*args) -> "opencascade::handle< Standard_Type >":
    r"""
    Returns the type attached to an object here, tshape (shape has no dynamic type).

    Parameters
    ----------
    ent: TopoDS_Shape

    Returns
    -------
    opencascade::handle<Standard_Type>

    """
    return _TransferBRep.TransferBRep_ShapeInfo_Type(*args)

def TransferBRep_ShapeInfo_TypeName(*args) -> "char const *":
    r"""
    Returns type name (string) here, the true name of the type of a shape.

    Parameters
    ----------
    ent: TopoDS_Shape

    Returns
    -------
    char *

    """
    return _TransferBRep.TransferBRep_ShapeInfo_TypeName(*args)

class TransferBRep_ShapeListBinder(OCC.Core.Transfer.Transfer_Binder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        list: TopTools_HSequenceOfShape

        Returns
        -------
        None

        """
        _TransferBRep.TransferBRep_ShapeListBinder_swiginit(self, _TransferBRep.new_TransferBRep_ShapeListBinder(*args))

    def AddResult(self, *args) -> "void":
        r"""
        Adds an item to the result list.

        Parameters
        ----------
        res: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_AddResult(self, *args)

    def CompSolid(self, *args) -> "TopoDS_CompSolid":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopoDS_CompSolid

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_CompSolid(self, *args)

    def Compound(self, *args) -> "TopoDS_Compound":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopoDS_Compound

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_Compound(self, *args)

    def Edge(self, *args) -> "TopoDS_Edge":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopoDS_Edge

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_Edge(self, *args)

    def Face(self, *args) -> "TopoDS_Face":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopoDS_Face

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_Face(self, *args)

    def NbShapes(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_NbShapes(self, *args)

    def Result(self, *args) -> "opencascade::handle< TopTools_HSequenceOfShape >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TopTools_HSequenceOfShape>

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_Result(self, *args)

    def SetResult(self, *args) -> "void":
        r"""
        Changes an already defined sub-result.

        Parameters
        ----------
        num: int
        res: TopoDS_Shape

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_SetResult(self, *args)

    def Shape(self, *args) -> "TopoDS_Shape const":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopoDS_Shape

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_Shape(self, *args)

    def ShapeType(self, *args) -> "TopAbs_ShapeEnum":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopAbs_ShapeEnum

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_ShapeType(self, *args)

    def Shell(self, *args) -> "TopoDS_Shell":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopoDS_Shell

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_Shell(self, *args)

    def Solid(self, *args) -> "TopoDS_Solid":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopoDS_Solid

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_Solid(self, *args)

    def Vertex(self, *args) -> "TopoDS_Vertex":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_Vertex(self, *args)

    def Wire(self, *args) -> "TopoDS_Wire":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        TopoDS_Wire

        """
        return _TransferBRep.TransferBRep_ShapeListBinder_Wire(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TransferBRep_ShapeListBinder_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TransferBRep.delete_TransferBRep_ShapeListBinder

# Register TransferBRep_ShapeListBinder in _TransferBRep:
_TransferBRep.TransferBRep_ShapeListBinder_swigregister(TransferBRep_ShapeListBinder)

class TransferBRep_ShapeMapper(OCC.Core.Transfer.Transfer_Finder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a mapper with a value. this value can then not be changed. it is used by the hasher to compute the hashcode, which will then be stored for an immediate reading.

        Parameters
        ----------
        akey: TopoDS_Shape

        Returns
        -------
        None

        """
        _TransferBRep.TransferBRep_ShapeMapper_swiginit(self, _TransferBRep.new_TransferBRep_ShapeMapper(*args))

    def Value(self, *args) -> "TopoDS_Shape const":
        r"""
        Returns the contained value.

        Returns
        -------
        TopoDS_Shape

        """
        return _TransferBRep.TransferBRep_ShapeMapper_Value(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TransferBRep_ShapeMapper_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TransferBRep.delete_TransferBRep_ShapeMapper

# Register TransferBRep_ShapeMapper in _TransferBRep:
_TransferBRep.TransferBRep_ShapeMapper_swigregister(TransferBRep_ShapeMapper)

class TransferBRep_TransferResultInfo(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates object with all fields nullified.

        Returns
        -------
        None

        """
        _TransferBRep.TransferBRep_TransferResultInfo_swiginit(self, _TransferBRep.new_TransferBRep_TransferResultInfo(*args))

    def Clear(self, *args) -> "void":
        r"""
        Resets all the fields.

        Returns
        -------
        None

        """
        return _TransferBRep.TransferBRep_TransferResultInfo_Clear(self, *args)

    def GetNoResult(self) -> "Standard_Integer":
        r"""GetNoResult(TransferBRep_TransferResultInfo self) -> Standard_Integer"""
        return _TransferBRep.TransferBRep_TransferResultInfo_GetNoResult(self)

    def SetNoResult(self, value: "Standard_Integer") -> "void":
        r"""SetNoResult(TransferBRep_TransferResultInfo self, Standard_Integer value)"""
        return _TransferBRep.TransferBRep_TransferResultInfo_SetNoResult(self, value)

    def GetNoResultFail(self) -> "Standard_Integer":
        r"""GetNoResultFail(TransferBRep_TransferResultInfo self) -> Standard_Integer"""
        return _TransferBRep.TransferBRep_TransferResultInfo_GetNoResultFail(self)

    def SetNoResultFail(self, value: "Standard_Integer") -> "void":
        r"""SetNoResultFail(TransferBRep_TransferResultInfo self, Standard_Integer value)"""
        return _TransferBRep.TransferBRep_TransferResultInfo_SetNoResultFail(self, value)

    def GetNoResultWarning(self) -> "Standard_Integer":
        r"""GetNoResultWarning(TransferBRep_TransferResultInfo self) -> Standard_Integer"""
        return _TransferBRep.TransferBRep_TransferResultInfo_GetNoResultWarning(self)

    def SetNoResultWarning(self, value: "Standard_Integer") -> "void":
        r"""SetNoResultWarning(TransferBRep_TransferResultInfo self, Standard_Integer value)"""
        return _TransferBRep.TransferBRep_TransferResultInfo_SetNoResultWarning(self, value)

    def GetNoResultWarningFail(self) -> "Standard_Integer":
        r"""GetNoResultWarningFail(TransferBRep_TransferResultInfo self) -> Standard_Integer"""
        return _TransferBRep.TransferBRep_TransferResultInfo_GetNoResultWarningFail(self)

    def SetNoResultWarningFail(self, value: "Standard_Integer") -> "void":
        r"""SetNoResultWarningFail(TransferBRep_TransferResultInfo self, Standard_Integer value)"""
        return _TransferBRep.TransferBRep_TransferResultInfo_SetNoResultWarningFail(self, value)

    def GetResult(self) -> "Standard_Integer":
        r"""GetResult(TransferBRep_TransferResultInfo self) -> Standard_Integer"""
        return _TransferBRep.TransferBRep_TransferResultInfo_GetResult(self)

    def SetResult(self, value: "Standard_Integer") -> "void":
        r"""SetResult(TransferBRep_TransferResultInfo self, Standard_Integer value)"""
        return _TransferBRep.TransferBRep_TransferResultInfo_SetResult(self, value)

    def GetResultFail(self) -> "Standard_Integer":
        r"""GetResultFail(TransferBRep_TransferResultInfo self) -> Standard_Integer"""
        return _TransferBRep.TransferBRep_TransferResultInfo_GetResultFail(self)

    def SetResultFail(self, value: "Standard_Integer") -> "void":
        r"""SetResultFail(TransferBRep_TransferResultInfo self, Standard_Integer value)"""
        return _TransferBRep.TransferBRep_TransferResultInfo_SetResultFail(self, value)

    def GetResultWarning(self) -> "Standard_Integer":
        r"""GetResultWarning(TransferBRep_TransferResultInfo self) -> Standard_Integer"""
        return _TransferBRep.TransferBRep_TransferResultInfo_GetResultWarning(self)

    def SetResultWarning(self, value: "Standard_Integer") -> "void":
        r"""SetResultWarning(TransferBRep_TransferResultInfo self, Standard_Integer value)"""
        return _TransferBRep.TransferBRep_TransferResultInfo_SetResultWarning(self, value)

    def GetResultWarningFail(self) -> "Standard_Integer":
        r"""GetResultWarningFail(TransferBRep_TransferResultInfo self) -> Standard_Integer"""
        return _TransferBRep.TransferBRep_TransferResultInfo_GetResultWarningFail(self)

    def SetResultWarningFail(self, value: "Standard_Integer") -> "void":
        r"""SetResultWarningFail(TransferBRep_TransferResultInfo self, Standard_Integer value)"""
        return _TransferBRep.TransferBRep_TransferResultInfo_SetResultWarningFail(self, value)


    @staticmethod
    def DownCast(t):
      return Handle_TransferBRep_TransferResultInfo_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TransferBRep.delete_TransferBRep_TransferResultInfo

# Register TransferBRep_TransferResultInfo in _TransferBRep:
_TransferBRep.TransferBRep_TransferResultInfo_swigregister(TransferBRep_TransferResultInfo)

class TransferBRep_ShapeBinder(TransferBRep_BinderOfShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an empty shapebinder.

        Returns
        -------
        None
        Creates a shapebinder with a result.

        Parameters
        ----------
        res: TopoDS_Shape

        Returns
        -------
        None

        """
        _TransferBRep.TransferBRep_ShapeBinder_swiginit(self, _TransferBRep.new_TransferBRep_ShapeBinder(*args))

    def CompSolid(self, *args) -> "TopoDS_CompSolid":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_CompSolid

        """
        return _TransferBRep.TransferBRep_ShapeBinder_CompSolid(self, *args)

    def Compound(self, *args) -> "TopoDS_Compound":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Compound

        """
        return _TransferBRep.TransferBRep_ShapeBinder_Compound(self, *args)

    def Edge(self, *args) -> "TopoDS_Edge":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Edge

        """
        return _TransferBRep.TransferBRep_ShapeBinder_Edge(self, *args)

    def Face(self, *args) -> "TopoDS_Face":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Face

        """
        return _TransferBRep.TransferBRep_ShapeBinder_Face(self, *args)

    def ShapeType(self, *args) -> "TopAbs_ShapeEnum":
        r"""
        Returns the type of the shape result (under topabs form).

        Returns
        -------
        TopAbs_ShapeEnum

        """
        return _TransferBRep.TransferBRep_ShapeBinder_ShapeType(self, *args)

    def Shell(self, *args) -> "TopoDS_Shell":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Shell

        """
        return _TransferBRep.TransferBRep_ShapeBinder_Shell(self, *args)

    def Solid(self, *args) -> "TopoDS_Solid":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Solid

        """
        return _TransferBRep.TransferBRep_ShapeBinder_Solid(self, *args)

    def Vertex(self, *args) -> "TopoDS_Vertex":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Vertex

        """
        return _TransferBRep.TransferBRep_ShapeBinder_Vertex(self, *args)

    def Wire(self, *args) -> "TopoDS_Wire":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Wire

        """
        return _TransferBRep.TransferBRep_ShapeBinder_Wire(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TransferBRep_ShapeBinder_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TransferBRep.delete_TransferBRep_ShapeBinder

# Register TransferBRep_ShapeBinder in _TransferBRep:
_TransferBRep.TransferBRep_ShapeBinder_swigregister(TransferBRep_ShapeBinder)

class TransferBRep_HSequenceOfTransferResultInfo(TransferBRep_SequenceOfTransferResultInfo, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TransferBRep.TransferBRep_HSequenceOfTransferResultInfo_swiginit(self, _TransferBRep.new_TransferBRep_HSequenceOfTransferResultInfo(*args))

    def Sequence(self) -> "TransferBRep_SequenceOfTransferResultInfo const &":
        return _TransferBRep.TransferBRep_HSequenceOfTransferResultInfo_Sequence(self)

    def Append(self, *args) -> "void":
        return _TransferBRep.TransferBRep_HSequenceOfTransferResultInfo_Append(self, *args)

    def ChangeSequence(self) -> "TransferBRep_SequenceOfTransferResultInfo &":
        return _TransferBRep.TransferBRep_HSequenceOfTransferResultInfo_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_TransferBRep_HSequenceOfTransferResultInfo_DownCast(t)

    __swig_destroy__ = _TransferBRep.delete_TransferBRep_HSequenceOfTransferResultInfo

# Register TransferBRep_HSequenceOfTransferResultInfo in _TransferBRep:
_TransferBRep.TransferBRep_HSequenceOfTransferResultInfo_swigregister(TransferBRep_HSequenceOfTransferResultInfo)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
GCPnts module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_gcpnts.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _GCPnts
else:
    import _GCPnts

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _GCPnts.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _GCPnts.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GCPnts.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _GCPnts.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _GCPnts.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _GCPnts.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _GCPnts.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _GCPnts.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _GCPnts.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _GCPnts.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GCPnts.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _GCPnts.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _GCPnts.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GCPnts.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _GCPnts.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _GCPnts.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _GCPnts.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _GCPnts:
_GCPnts.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _GCPnts.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD

from enum import IntEnum
from OCC.Core.Exception import *

GCPnts_Linear = _GCPnts.GCPnts_Linear
GCPnts_Circular = _GCPnts.GCPnts_Circular
GCPnts_Curved = _GCPnts.GCPnts_Curved
GCPnts_DefComposite = _GCPnts.GCPnts_DefComposite
GCPnts_LengthParametrized = _GCPnts.GCPnts_LengthParametrized
GCPnts_Parametrized = _GCPnts.GCPnts_Parametrized
GCPnts_AbsComposite = _GCPnts.GCPnts_AbsComposite


class GCPnts_DeflectionType(IntEnum):
	GCPnts_Linear = 0
	GCPnts_Circular = 1
	GCPnts_Curved = 2
	GCPnts_DefComposite = 3
GCPnts_Linear = GCPnts_DeflectionType.GCPnts_Linear
GCPnts_Circular = GCPnts_DeflectionType.GCPnts_Circular
GCPnts_Curved = GCPnts_DeflectionType.GCPnts_Curved
GCPnts_DefComposite = GCPnts_DeflectionType.GCPnts_DefComposite

class GCPnts_AbscissaType(IntEnum):
	GCPnts_LengthParametrized = 0
	GCPnts_Parametrized = 1
	GCPnts_AbsComposite = 2
GCPnts_LengthParametrized = GCPnts_AbscissaType.GCPnts_LengthParametrized
GCPnts_Parametrized = GCPnts_AbscissaType.GCPnts_Parametrized
GCPnts_AbsComposite = GCPnts_AbscissaType.GCPnts_AbsComposite

class GCPnts_AbscissaPoint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Abscissa: float
        U0: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0> with the given tolerance.

        Parameters
        ----------
        Tol: float
        C: Adaptor3d_Curve
        Abscissa: float
        U0: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0> with the given tolerance.

        Parameters
        ----------
        Tol: float
        C: Adaptor2d_Curve2d
        Abscissa: float
        U0: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Abscissa: float
        U0: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>. <ui> is the starting value used in the iterative process which find the solution, it must be close to the final solution.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Abscissa: float
        U0: float
        Ui: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>. <ui> is the starting value used in the iterative process which find the solution, it must be closed to the final solution.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Abscissa: float
        U0: float
        Ui: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>. <ui> is the starting value used in the iterative process which find the solution, it must be close to the final solution.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Abscissa: float
        U0: float
        Ui: float
        Tol: float

        Returns
        -------
        None
        The algorithm computes a point on a curve <curve> at the distance <abscissa> from the point of parameter <u0>. <ui> is the starting value used in the iterative process which find the solution, it must be close to the final solution.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Abscissa: float
        U0: float
        Ui: float
        Tol: float

        Returns
        -------
        None

        """
        _GCPnts.GCPnts_AbscissaPoint_swiginit(self, _GCPnts.new_GCPnts_AbscissaPoint(*args))

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        True if the computation was successful, false otherwise. isdone is a protection against: - non-convergence of the algorithm - querying the results before computation.

        Returns
        -------
        bool

        """
        return _GCPnts.GCPnts_AbscissaPoint_IsDone(self, *args)

    @staticmethod
    def Length(*args) -> "Standard_Real":
        r"""
        Computes the length of the curve <c>.

        Parameters
        ----------
        C: Adaptor3d_Curve

        Returns
        -------
        float
        Computes the length of the curve <c>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d

        Returns
        -------
        float
        Computes the length of the curve <c> with the given tolerance.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Tol: float

        Returns
        -------
        float
        Computes the length of the curve <c> with the given tolerance.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Tol: float

        Returns
        -------
        float
        Computes the length of the curve <c>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        U1: float
        U2: float

        Returns
        -------
        float
        Computes the length of the curve <c>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        U1: float
        U2: float

        Returns
        -------
        float
        Computes the length of the curve <c> with the given tolerance.

        Parameters
        ----------
        C: Adaptor3d_Curve
        U1: float
        U2: float
        Tol: float

        Returns
        -------
        float
        Computes the length of the curve <c> with the given tolerance. constructs an empty algorithm. this function is used only for initializing a framework to compute the length of a curve (or a series of curves). warning the function isdone will return the value false after the use of this function.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        U1: float
        U2: float
        Tol: float

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_AbscissaPoint_Length(*args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the curve of the point solution of this algorithm. exceptions stdfail_notdone if the computation was not successful, or was not done.

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_AbscissaPoint_Parameter(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCPnts.delete_GCPnts_AbscissaPoint

# Register GCPnts_AbscissaPoint in _GCPnts:
_GCPnts.GCPnts_AbscissaPoint_swigregister(GCPnts_AbscissaPoint)

def GCPnts_AbscissaPoint_Length(*args) -> "Standard_Real":
    r"""
    Computes the length of the curve <c>.

    Parameters
    ----------
    C: Adaptor3d_Curve

    Returns
    -------
    float
    Computes the length of the curve <c>.

    Parameters
    ----------
    C: Adaptor2d_Curve2d

    Returns
    -------
    float
    Computes the length of the curve <c> with the given tolerance.

    Parameters
    ----------
    C: Adaptor3d_Curve
    Tol: float

    Returns
    -------
    float
    Computes the length of the curve <c> with the given tolerance.

    Parameters
    ----------
    C: Adaptor2d_Curve2d
    Tol: float

    Returns
    -------
    float
    Computes the length of the curve <c>.

    Parameters
    ----------
    C: Adaptor3d_Curve
    U1: float
    U2: float

    Returns
    -------
    float
    Computes the length of the curve <c>.

    Parameters
    ----------
    C: Adaptor2d_Curve2d
    U1: float
    U2: float

    Returns
    -------
    float
    Computes the length of the curve <c> with the given tolerance.

    Parameters
    ----------
    C: Adaptor3d_Curve
    U1: float
    U2: float
    Tol: float

    Returns
    -------
    float
    Computes the length of the curve <c> with the given tolerance. constructs an empty algorithm. this function is used only for initializing a framework to compute the length of a curve (or a series of curves). warning the function isdone will return the value false after the use of this function.

    Parameters
    ----------
    C: Adaptor2d_Curve2d
    U1: float
    U2: float
    Tol: float

    Returns
    -------
    float

    """
    return _GCPnts.GCPnts_AbscissaPoint_Length(*args)

class GCPnts_DistFunction2dMV(OCC.Core.math.math_MultipleVarFunction):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theCurvLinDist: GCPnts_DistFunction2d

        Returns
        -------
        None

        """
        _GCPnts.GCPnts_DistFunction2dMV_swiginit(self, _GCPnts.new_GCPnts_DistFunction2dMV(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _GCPnts.delete_GCPnts_DistFunction2dMV

# Register GCPnts_DistFunction2dMV in _GCPnts:
_GCPnts.GCPnts_DistFunction2dMV_swigregister(GCPnts_DistFunction2dMV)

class GCPnts_DistFunctionMV(OCC.Core.math.math_MultipleVarFunction):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theCurvLinDist: GCPnts_DistFunction

        Returns
        -------
        None

        """
        _GCPnts.GCPnts_DistFunctionMV_swiginit(self, _GCPnts.new_GCPnts_DistFunctionMV(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _GCPnts.delete_GCPnts_DistFunctionMV

# Register GCPnts_DistFunctionMV in _GCPnts:
_GCPnts.GCPnts_DistFunctionMV_swigregister(GCPnts_DistFunctionMV)

class GCPnts_QuasiUniformAbscissa(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty algorithm. to define the problem to be solved, use the function initialize.

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points - on the curve c where abscissa is the curvilinear distance between two consecutive points of the distribution.

        Parameters
        ----------
        C: Adaptor3d_Curve
        NbPoints: int

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on the part of curve c limited by the two parameter values u1 and u2, where abscissa is the curvilinear distance between two consecutive points of the distribution. the first point of the distribution is either the origin of curve c or the point of parameter u1. the following points are computed such that the curvilinear distance between two consecutive points is equal to abscissa. the last point of the distribution is either the end point of curve c or the point of parameter u2. however the curvilinear distance between this last point and the point just preceding it in the distribution is, of course, generally not equal to abscissa. use the function isdone to verify that the computation was successful, the function nbpoints to obtain the number of points of the computed distribution, and the function parameter to read the parameter of each point. warning the roles of u1 and u2 are inverted if u1 > u2 . warning c is an adapted curve, that is, an object which is an interface between: - the services provided by either a 2d curve from the package geom2d (in the case of an adaptor2d_curve2d curve) or a 3d curve from the package geom (in the case of an adaptor3d_curve curve), - and those required on the curve by the computation algorithm.

        Parameters
        ----------
        C: Adaptor3d_Curve
        NbPoints: int
        U1: float
        U2: float

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on the curve2d <c>. <nbpoints> defines the nomber of desired points.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        NbPoints: int

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on a part of the curve2d <c>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        NbPoints: int
        U1: float
        U2: float

        Returns
        -------
        None

        """
        _GCPnts.GCPnts_QuasiUniformAbscissa_swiginit(self, _GCPnts.new_GCPnts_QuasiUniformAbscissa(*args))

    def Initialize(self, *args) -> "void":
        r"""
        Initialize the algoritms with <c>, <nbpoints> and.

        Parameters
        ----------
        C: Adaptor3d_Curve
        NbPoints: int

        Returns
        -------
        None
        Initialize the algoritms with <c>, <abscissa>, <u1>, <u2>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        NbPoints: int
        U1: float
        U2: float

        Returns
        -------
        None
        Initialize the algoritms with <c>, <nbpoints> and.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        NbPoints: int

        Returns
        -------
        None
        Initialize the algoritms with <c>, <abscissa>, <u1>, <u2>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        NbPoints: int
        U1: float
        U2: float

        Returns
        -------
        None

        """
        return _GCPnts.GCPnts_QuasiUniformAbscissa_Initialize(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the computation was successful. isdone is a protection against: - non-convergence of the algorithm - querying the results before computation.

        Returns
        -------
        bool

        """
        return _GCPnts.GCPnts_QuasiUniformAbscissa_IsDone(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of points of the distribution computed by this algorithm. this value is either: - the one imposed on the algorithm at the time of construction (or initialization), or - the one computed by the algorithm when the curvilinear distance between two consecutive points of the distribution is imposed on the algorithm at the time of construction (or initialization). exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Returns
        -------
        int

        """
        return _GCPnts.GCPnts_QuasiUniformAbscissa_NbPoints(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the point of index index in the distribution computed by this algorithm. warning index must be greater than or equal to 1, and less than or equal to the number of points of the distribution. however, pay particular attention as this condition is not checked by this function. exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_QuasiUniformAbscissa_Parameter(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCPnts.delete_GCPnts_QuasiUniformAbscissa

# Register GCPnts_QuasiUniformAbscissa in _GCPnts:
_GCPnts.GCPnts_QuasiUniformAbscissa_swigregister(GCPnts_QuasiUniformAbscissa)

class GCPnts_QuasiUniformDeflection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty algorithm. to define the problem to be solved, use the function initialize.

        Returns
        -------
        None
        Computes a quasiuniform deflection distribution of points on the curve <c>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C1

        Returns
        -------
        None
        Computes a quasiuniform deflection distribution of points on the curve <c>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C1

        Returns
        -------
        None
        Computes a quasiuniform deflection distribution of points on a part of the curve <c>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        U1: float
        U2: float
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C1

        Returns
        -------
        None
        Computes a quasiuniform deflection distribution of points on a part of the curve <c>. this and the above algorithms compute a distribution of points: - on the curve c, or - on the part of curve c limited by the two parameter values u1 and u2, where the deflection resulting from the distributed points is not greater than deflection. the first point of the distribution is either the origin of curve c or the point of parameter u1. the last point of the distribution is either the end point of curve c or the point of parameter u2. intermediate points of the distribution are built such that the deflection is not greater than deflection. using the following evaluation of the deflection: if pi and pj are two consecutive points of the distribution, respectively of parameter ui and uj on the curve, the deflection is the distance between: - the mid-point of pi and pj (the center of the chord joining these two points) - and the point of mid-parameter of these two points (the point of parameter [(ui+uj) / 2 ] on curve c). continuity, defaulted to geomabs_c1, gives the degree of continuity of the curve c. (note that c is an adaptor3d_curve or an adaptor2d_curve2d object, and does not know the degree of continuity of the underlying curve). use the function isdone to verify that the computation was successful, the function nbpoints to obtain the number of points of the computed distribution, and the function parameter to read the parameter of each point. warning - the roles of u1 and u2 are inverted if u1 > u2. - derivative functions on the curve are called according to continuity. an error may occur if continuity is greater than the real degree of continuity of the curve. warning c is an adapted curve, i.e. an object which is an interface between: - the services provided by either a 2d curve from the package geom2d (in the case of an adaptor2d_curve2d curve) or a 3d curve from the package geom (in the case of an adaptor3d_curve curve), - and those required on the curve by the computation algorithm.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        U1: float
        U2: float
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C1

        Returns
        -------
        None

        """
        _GCPnts.GCPnts_QuasiUniformDeflection_swiginit(self, _GCPnts.new_GCPnts_QuasiUniformDeflection(*args))

    def Deflection(self, *args) -> "Standard_Real":
        r"""
        Returns the deflection between the curve and the polygon resulting from the points of the distribution computed by this algorithm. this is the value given to the algorithm at the time of construction (or initialization). exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_QuasiUniformDeflection_Deflection(self, *args)

    def Initialize(self, *args) -> "void":
        r"""
        Initialize the algoritms with <c>, <deflection>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <deflection>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <deflection>, <u1>,<u2>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        U1: float
        U2: float
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <deflection>, -- <u1>,<u2> this and the above algorithms initialize (or reinitialize) this algorithm and compute a distribution of points: - on the curve c, or - on the part of curve c limited by the two parameter values u1 and u2, where the deflection resulting from the distributed points is not greater than deflection. the first point of the distribution is either the origin of curve c or the point of parameter u1. the last point of the distribution is either the end point of curve c or the point of parameter u2. intermediate points of the distribution are built in such a way that the deflection is not greater than deflection. using the following evaluation of the deflection: if pi and pj are two consecutive points of the distribution, respectively of parameter ui and uj on the curve, the deflection is the distance between: - the mid-point of pi and pj (the center of the chord joining these two points) - and the point of mid-parameter of these two points (the point of parameter [(ui+uj) / 2 ] on curve c). continuity, defaulted to geomabs_c1, gives the degree of continuity of the curve c. (note that c is an adaptor3d_curve or an adaptor2d_curve2d object, and does not know the degree of continuity of the underlying curve). use the function isdone to verify that the computation was successful, the function nbpoints to obtain the number of points of the computed distribution, and the function parameter to read the parameter of each point. warning - the roles of u1 and u2 are inverted if u1 > u2. - derivative functions on the curve are called according to continuity. an error may occur if continuity is greater than the real degree of continuity of the curve. warning c is an adapted curve, i.e. an object which is an interface between: - the services provided by either a 2d curve from the package geom2d (in the case of an adaptor2d_curve2d curve) or a 3d curve from the package geom (in the case of an adaptor3d_curve curve), and those required on the curve by the computation algorithm.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        U1: float
        U2: float
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C1

        Returns
        -------
        None

        """
        return _GCPnts.GCPnts_QuasiUniformDeflection_Initialize(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the computation was successful. isdone is a protection against: - non-convergence of the algorithm - querying the results before computation.

        Returns
        -------
        bool

        """
        return _GCPnts.GCPnts_QuasiUniformDeflection_IsDone(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of points of the distribution computed by this algorithm. exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Returns
        -------
        int

        """
        return _GCPnts.GCPnts_QuasiUniformDeflection_NbPoints(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the point of index index in the distribution computed by this algorithm. warning index must be greater than or equal to 1, and less than or equal to the number of points of the distribution. however, pay particular attention as this condition is not checked by this function. exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_QuasiUniformDeflection_Parameter(self, *args)

    def Value(self, *args) -> "gp_Pnt":
        r"""
        Returns the point of index index in the distribution computed by this algorithm. warning index must be greater than or equal to 1, and less than or equal to the number of points of the distribution. however, pay particular attention as this condition is not checked by this function. exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Pnt

        """
        return _GCPnts.GCPnts_QuasiUniformDeflection_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCPnts.delete_GCPnts_QuasiUniformDeflection

# Register GCPnts_QuasiUniformDeflection in _GCPnts:
_GCPnts.GCPnts_QuasiUniformDeflection_swigregister(GCPnts_QuasiUniformDeflection)

class GCPnts_TangentialDeflection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Adaptor3d_Curve
        AngularDeflection: float
        CurvatureDeflection: float
        MinimumOfPoints: int,optional
        	default value is 2
        UTol: float,optional
        	default value is 1.0e-9
        theMinLen: float,optional
        	default value is 1.0e-7

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Adaptor3d_Curve
        FirstParameter: float
        LastParameter: float
        AngularDeflection: float
        CurvatureDeflection: float
        MinimumOfPoints: int,optional
        	default value is 2
        UTol: float,optional
        	default value is 1.0e-9
        theMinLen: float,optional
        	default value is 1.0e-7

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        AngularDeflection: float
        CurvatureDeflection: float
        MinimumOfPoints: int,optional
        	default value is 2
        UTol: float,optional
        	default value is 1.0e-9
        theMinLen: float,optional
        	default value is 1.0e-7

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        FirstParameter: float
        LastParameter: float
        AngularDeflection: float
        CurvatureDeflection: float
        MinimumOfPoints: int,optional
        	default value is 2
        UTol: float,optional
        	default value is 1.0e-9
        theMinLen: float,optional
        	default value is 1.0e-7

        Returns
        -------
        None

        """
        _GCPnts.GCPnts_TangentialDeflection_swiginit(self, _GCPnts.new_GCPnts_TangentialDeflection(*args))

    def AddPoint(self, *args) -> "Standard_Integer":
        r"""
        Add point to already calculated points (or replace existing) returns index of new added point or founded with parametric tolerance (replaced if theisreplace is true).

        Parameters
        ----------
        thePnt: gp_Pnt
        theParam: float
        theIsReplace: bool,optional
        	default value is Standard_True

        Returns
        -------
        int

        """
        return _GCPnts.GCPnts_TangentialDeflection_AddPoint(self, *args)

    @staticmethod
    def ArcAngularStep(*args) -> "Standard_Real":
        r"""
        Computes angular step for the arc using the given parameters.

        Parameters
        ----------
        theRadius: float
        theLinearDeflection: float
        theAngularDeflection: float
        theMinLength: float

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_TangentialDeflection_ArcAngularStep(*args)

    def Initialize(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        C: Adaptor3d_Curve
        AngularDeflection: float
        CurvatureDeflection: float
        MinimumOfPoints: int,optional
        	default value is 2
        UTol: float,optional
        	default value is 1.0e-9
        theMinLen: float,optional
        	default value is 1.0e-7

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Adaptor3d_Curve
        FirstParameter: float
        LastParameter: float
        AngularDeflection: float
        CurvatureDeflection: float
        MinimumOfPoints: int,optional
        	default value is 2
        UTol: float,optional
        	default value is 1.0e-9
        theMinLen: float,optional
        	default value is 1.0e-7

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        AngularDeflection: float
        CurvatureDeflection: float
        MinimumOfPoints: int,optional
        	default value is 2
        UTol: float,optional
        	default value is 1.0e-9
        theMinLen: float,optional
        	default value is 1.0e-7

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        FirstParameter: float
        LastParameter: float
        AngularDeflection: float
        CurvatureDeflection: float
        MinimumOfPoints: int,optional
        	default value is 2
        UTol: float,optional
        	default value is 1.0e-9
        theMinLen: float,optional
        	default value is 1.0e-7

        Returns
        -------
        None

        """
        return _GCPnts.GCPnts_TangentialDeflection_Initialize(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _GCPnts.GCPnts_TangentialDeflection_NbPoints(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_TangentialDeflection_Parameter(self, *args)

    def Value(self, *args) -> "gp_Pnt":
        r"""
        No available documentation.

        Parameters
        ----------
        I: int

        Returns
        -------
        gp_Pnt

        """
        return _GCPnts.GCPnts_TangentialDeflection_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCPnts.delete_GCPnts_TangentialDeflection

# Register GCPnts_TangentialDeflection in _GCPnts:
_GCPnts.GCPnts_TangentialDeflection_swigregister(GCPnts_TangentialDeflection)

def GCPnts_TangentialDeflection_ArcAngularStep(*args) -> "Standard_Real":
    r"""
    Computes angular step for the arc using the given parameters.

    Parameters
    ----------
    theRadius: float
    theLinearDeflection: float
    theAngularDeflection: float
    theMinLength: float

    Returns
    -------
    float

    """
    return _GCPnts.GCPnts_TangentialDeflection_ArcAngularStep(*args)

class GCPnts_UniformAbscissa(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creation of a indefinite uniformabscissa.

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on the curve <c>. parameter toler is equal precision::confusion by default. it is used for more precise calculation of curve length.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Abscissa: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on a part of the curve <c>. parameter toler is equal precision::confusion by default. it is used for more precise calculation of curve length.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Abscissa: float
        U1: float
        U2: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on the curve <c>. <nbpoints> defines the nomber of desired points. parameter toler is equal precision::confusion by default. it is used for more precise calculation of curve length.

        Parameters
        ----------
        C: Adaptor3d_Curve
        NbPoints: int
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on a part of the curve <c>. parameter toler is equal precision::confusion by default. it is used for more precise calculation of curve length.

        Parameters
        ----------
        C: Adaptor3d_Curve
        NbPoints: int
        U1: float
        U2: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on the curve2d <c>. parameter toler is equal precision::confusion by default. it is used for more precise calculation of curve length.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Abscissa: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on a part of the curve2d <c>. parameter toler is equal precision::confusion by default. it is used for more precise calculation of curve length.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Abscissa: float
        U1: float
        U2: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on the curve2d <c>. <nbpoints> defines the nomber of desired points. parameter toler is equal precision::confusion by default. it is used for more precise calculation of curve length.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        NbPoints: int
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Computes a uniform abscissa distribution of points on a part of the curve2d <c>. parameter toler is equal precision::confusion by default. it is used for more precise calculation of curve length.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        NbPoints: int
        U1: float
        U2: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None

        """
        _GCPnts.GCPnts_UniformAbscissa_swiginit(self, _GCPnts.new_GCPnts_UniformAbscissa(*args))

    def Abscissa(self, *args) -> "Standard_Real":
        r"""
        Returne the current abscissa ie the distance between two consecutive points.

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_UniformAbscissa_Abscissa(self, *args)

    def Initialize(self, *args) -> "void":
        r"""
        Initialize the algoritms with <c>, <abscissa>, <toler>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Abscissa: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <abscissa>, <u1>, <u2>, <toler>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Abscissa: float
        U1: float
        U2: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <nbpoints>, <toler> and.

        Parameters
        ----------
        C: Adaptor3d_Curve
        NbPoints: int
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <abscissa>, <u1>, <u2>, <toler>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        NbPoints: int
        U1: float
        U2: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <abscissa>, <toler>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Abscissa: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <abscissa>, <u1>, <u2>, <toler>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Abscissa: float
        U1: float
        U2: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <nbpoints>, <toler> and.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        NbPoints: int
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None
        Initialize the algoritms with <c>, <abscissa>, <u1>, <u2>, <toler>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        NbPoints: int
        U1: float
        U2: float
        Toler: float,optional
        	default value is -1

        Returns
        -------
        None

        """
        return _GCPnts.GCPnts_UniformAbscissa_Initialize(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _GCPnts.GCPnts_UniformAbscissa_IsDone(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _GCPnts.GCPnts_UniformAbscissa_NbPoints(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the computed parameter of index <index>.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_UniformAbscissa_Parameter(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCPnts.delete_GCPnts_UniformAbscissa

# Register GCPnts_UniformAbscissa in _GCPnts:
_GCPnts.GCPnts_UniformAbscissa_swigregister(GCPnts_UniformAbscissa)

class GCPnts_UniformDeflection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty algorithm. to define the problem to be solved, use the function initialize.

        Returns
        -------
        None
        Computes a uniform deflection distribution of points on the curve <c>. if <withcontrol> is true,the algorithm controls the estimate deflection.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Computes a uniform deflection distribution of points on the curve <c>. if <withcontrol> is true,the algorithm controls the estimate deflection.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Computes a uniform deflection distribution of points on a part of the curve <c>. if <withcontrol> is true,the algorithm controls the estimate deflection.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        U1: float
        U2: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Computes a uniform deflection distribution of points on a part of the curve <c>. if <withcontrol> is true,the algorithm controls the estimate deflection.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        U1: float
        U2: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        _GCPnts.GCPnts_UniformDeflection_swiginit(self, _GCPnts.new_GCPnts_UniformDeflection(*args))

    def Deflection(self, *args) -> "Standard_Real":
        r"""
        Returns the deflection between the curve and the polygon resulting from the points of the distribution computed by this algorithm. this value is the one given to the algorithm at the time of construction (or initialization). exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_UniformDeflection_Deflection(self, *args)

    def Initialize(self, *args) -> "void":
        r"""
        Initialize the algoritms with <c>, <deflection>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Initialize the algoritms with <c>, <deflection>.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Initialize the algoritms with <c>, <deflection>, <u1>,<u2>.

        Parameters
        ----------
        C: Adaptor3d_Curve
        Deflection: float
        U1: float
        U2: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Initialize the algoritms with <c>, <deflection>, <u1>,<u2> this and the above methods initialize (or reinitialize) this algorithm and compute a distribution of points: - on the curve c, or - on the part of curve c limited by the two parameter values u1 and u2, where the maximum distance between c and the polygon that results from the points of the distribution is not greater than deflection. the first point of the distribution is either the origin of curve c or the point of parameter u1. the last point of the distribution is either the end point of curve c or the point of parameter u2. intermediate points of the distribution are built using interpolations of segments of the curve limited at the 2nd degree. the construction ensures, in a first step, that the chordal deviation for this interpolation of the curve is less than or equal to deflection. however, it does not ensure that the chordal deviation for the curve itself is less than or equal to deflection. to do this a check is necessary, which may generate (second step) additional intermediate points. this check is time consuming, and can be avoided by setting withcontrol to false. note that by default withcontrol is true and check is performed. use the function isdone to verify that the computation was successful, the function nbpoints to obtain the number of points of the computed distribution, and the function parameter to read the parameter of each point. warning - c is necessary, 'c2' continuous. this property is not checked at construction time. - the roles of u1 and u2 are inverted if u1 > u2. warning c is an adapted curve, i.e. an object which is an interface between: - the services provided by either a 2d curve from the package geom2d (in the case of an adaptor2d_curve2d curve) or a 3d curve from the package geom (in the case of an adaptor3d_curve curve), - and those required on the curve by the computation algorithm.

        Parameters
        ----------
        C: Adaptor2d_Curve2d
        Deflection: float
        U1: float
        U2: float
        WithControl: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _GCPnts.GCPnts_UniformDeflection_Initialize(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the computation was successful. isdone is a protection against: - non-convergence of the algorithm - querying the results before computation.

        Returns
        -------
        bool

        """
        return _GCPnts.GCPnts_UniformDeflection_IsDone(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of points of the distribution computed by this algorithm. exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Returns
        -------
        int

        """
        return _GCPnts.GCPnts_UniformDeflection_NbPoints(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the point of index index in the distribution computed by this algorithm. warning index must be greater than or equal to 1, and less than or equal to the number of points of the distribution. however, pay particular attention as this condition is not checked by this function. exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _GCPnts.GCPnts_UniformDeflection_Parameter(self, *args)

    def Value(self, *args) -> "gp_Pnt":
        r"""
        Returns the point of index index in the distribution computed by this algorithm. warning index must be greater than or equal to 1, and less than or equal to the number of points of the distribution. however, pay particular attention as this condition is not checked by this function. exceptions stdfail_notdone if this algorithm has not been initialized, or if the computation was not successful.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Pnt

        """
        return _GCPnts.GCPnts_UniformDeflection_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _GCPnts.delete_GCPnts_UniformDeflection

# Register GCPnts_UniformDeflection in _GCPnts:
_GCPnts.GCPnts_UniformDeflection_swigregister(GCPnts_UniformDeflection)


@classnotwrapped
class GCPnts_DistFunction:
	pass

@classnotwrapped
class GCPnts_DistFunction2d:
	pass






